## ⚙️ Install

```bash
pip install pipd
```

## Usage

### `pipe`

### `batch`

### `unbatch`

### `buffer`

### `map`

### `filter`

### `unpipe`

### `limit`

### `tqdm`

### `log`

### `sleep`

### `readf`

### `readl`

### `writel`

### `filter_cached`

### `run`
